Exception: Logtide::Transport::NetworkError
- Defined in:
- lib/logtide/transport/http.rb
Overview
Raised when a batch cannot be delivered due to a network/transport problem. These failures are retryable (spec 002 section 6).
Raised when a batch cannot be delivered due to a network/transport problem. These failures are retryable (spec 002 section 6).